import json
import logging
import os
from flask import Flask
from flask_cors import CORS
from flask_restful import Api

from endpoints.client import Client, ClientList
from endpoints.notify import Notify
from endpoints.receive import Receive
from endpoints.send import Send
from endpoints.token import Token
from endpoints.queues import Queue, QueueList
from models.token_model import TokenModel
from logger import setup_logging


setup_logging()
token = TokenModel()
token.setSecret()


def get_config():
    config = {"cors": {r"*": {"origins": "http://localhost:*"}}}
    try:
        with open("./data/api-config.json", "r") as config_file:
            config = {
                r"{}".format(key): value
                for key, value in json.load(config_file).items()
            }
    except FileNotFoundError:
        logging.info("No API config: Using default")
    return config


def create_app():
    app = Flask(__name__)
    api = Api(app)
    api_config = get_config()
    logging.debug(str(api_config))
    CORS(app, resources=api_config["cors"])

    api.add_resource(ClientList, "/client")
    api.add_resource(Client, "/client/<client_id>")
    api.add_resource(Receive, "/receive")
    api.add_resource(Send, "/send")
    api.add_resource(Notify, "/notify")
    api.add_resource(Token, "/token")
    api.add_resource(QueueList, "/queue")
    api.add_resource(Queue, "/queue/<queue_name>")
    return app


flask_host = os.getenv(
    "FLASK_HOST", "localhost"
)  # Sets to whatever MQ_HOST is, or defaults to localhost

if __name__ == "__main__":
    app = create_app()
    app.run(debug=False, port=8087, host=flask_host)
