"""
Create a set of client credentials programmatically or return existing 
if a client matching the id has already been configured. 

Usage: client_create.py \
    --id=soar-hydrogen \
    --name="Hydrogen Interface" \
    --sub="soar.#" \
    --api="https://nucleus.noc.ac.uk/soar/api" \
    [--silent] 

"""
import argparse
import json

from models.client_model import ClientModel

parser = argparse.ArgumentParser(
    prog="PROG", formatter_class=argparse.ArgumentDefaultsHelpFormatter
)
parser.add_argument(
    "--id",
    type=str,
    default="admin",
    help="Client IDs should be human readable kebab-case and unique",
)
parser.add_argument(
    "--name",
    type=str,
    default="Admin Client",
    help="Client names are how the client will appear on screen",
)
parser.add_argument(
    "--sub",
    type=str,
    default="#",
    help="A rabbitmq topic pattern for the client to subscribe to *=one-word-wildcard #=multi-word-wildcard",
)

parser.add_argument(
    "--api",
    type=str,
    default="http://localhost:8087",
    help="The root api endpoint",
)

parser.add_argument("--silent", action="store_true")
parser.set_defaults(silent=False)

args = parser.parse_args()

if not args.silent:
    parser.print_help()

client_model = ClientModel()

# Get existing client if already exists
client = client_model.find(args.id)

if not client:
    client = client_model.add(
        {
            "client_id": args.id,
            "client_name": args.name,
            "subscription": args.sub,
        }
    )

# Add the API endpoint to the credentials file
client["api"] = args.api

if not args.silent:
    print("Here is your credentials file:")

print(json.dumps(client, indent=2))
