from flask_restful import request, abort
from marshmallow import Schema, fields
from endpoints.auth_resource import AuthResource
from models.client_model import ClientModel
from rmq import get_queue_status, empty_queue


class Queue(AuthResource):
    def get(self, queue_name):
        allow = self.auth(request)
        if allow:
            queue_status = get_queue_status(queue_name)
            return {"queue": queue_name, "properties": queue_status}

    def delete(self, queue_name):
        allow = self.auth(request)
        if allow:
            emptied = empty_queue(queue_name)
            queue_status = get_queue_status(queue_name)
            queue_status["empty"] = emptied
            return {"queue": queue_name, "properties": queue_status}


class QueueList(AuthResource):
    def __init__(self):
        super().__init__()
        self.clients_file = ClientModel()

    def get(self):
        allow = self.auth(request)
        if allow:
            queue_status = {
                client_id: {
                    "inbox": get_queue_status(f"{client_id}-inbox"),
                    "outbox": get_queue_status(f"{client_id}-outbox"),
                    "broadcast": get_queue_status(f"{client_id}-broadcast"),
                }
                for client_id in self.clients_file.get().keys()
            }
            return [
                {
                    "client_id": client_id,
                    "queue": f"{client_id}-{queue_type}",
                    "type": queue_type,
                    "properties": queue_status,
                }
                for client_id, client_queues in queue_status.items()
                for queue_type, queue_status in client_queues.items()
            ]
