"""
Setup logging module settings 

Get log level from env or default to INFO
Downgrade logging for noisy packages

Python logging doesn't have a level higher 
than DEBUG 
Logging the full messages creates a lot of 
extra log data which is not needed most of 
the time.
"""
import logging
import os


def setup_logging():
    # Add TRACE level for logging full message content
    TRACE_LEVEL = 9
    logging.addLevelName(TRACE_LEVEL, "TRACE")

    def logger_trace(self, message, *args, **kws):
        self._log(TRACE_LEVEL, message, args, **kws)

    def trace(message, *args, **kwargs):
        logger = logging.getLogger()
        if logger.isEnabledFor(TRACE_LEVEL):
            logger.trace(message, *args, **kwargs)

    logging.Logger.trace = logger_trace
    logging.trace = trace

    # Set log level from env var or default if not set
    LOG_LEVEL = logging.getLevelName(os.getenv("LOG_LEVEL", "INFO"))
    LOG_FORMAT = "%(asctime)s %(levelname)s %(name)s %(message)s"
    logging.basicConfig(level=LOG_LEVEL, format=LOG_FORMAT, datefmt="%Y-%m-%dT%H:%M:%S")

    # Downgrade log level for pika/watchdog which are noisy in DEBUG mode
    logging.getLogger("pika").setLevel(logging.ERROR)
    logging.getLogger("watchdog").setLevel(logging.ERROR)
