import flask
import json
import pytest
from unittest.mock import patch, mock_open, call
from werkzeug.exceptions import HTTPException
from api import create_app


@pytest.mark.usefixtures("mock_clients")
def test_get_client(mock_clients):
    app = create_app()
    with patch(
        "builtins.open", mock_open(read_data=json.dumps(mock_clients))
    ) as mock_file_open, patch(
        "os.path.getmtime", return_value=3
    ) as mock_getmtime, app.test_client() as app_test_client:
        response = app_test_client.get("/client")
        assert response.status_code == 200
        assert len(response.json.keys()) == 2
        assert "client-1" in response.json


@pytest.mark.usefixtures("mock_clients")
def test_get_client_1(mock_clients):
    app = create_app()
    with patch(
        "builtins.open", mock_open(read_data=json.dumps(mock_clients))
    ) as mock_file_open, patch(
        "os.path.getmtime", return_value=3
    ) as mock_getmtime, app.test_client() as app_test_client:
        response = app_test_client.get("/client/client-1")
        assert response.status_code == 200
        assert "client_id" in response.json
        assert response.json["client_id"] == "client-1"
        assert "client_name" in response.json
        assert "secret" not in response.json


@pytest.mark.usefixtures("mock_clients", "mock_new_client")
def test_post_client(mock_clients, mock_new_client):
    app = create_app()
    with patch(
        "builtins.open", mock_open(read_data=json.dumps(mock_clients))
    ) as mock_file_open, patch(
        "os.path.getmtime", return_value=3
    ) as mock_getmtime, app.test_client() as app_test_client:
        response = app_test_client.post("/client", json=mock_new_client)
        assert response.status_code == 201
        assert "client_id" in response.json
        assert response.json["client_id"] == "client-3"
        assert "client_name" in response.json
        assert "secret" in response.json


@pytest.mark.usefixtures("mock_clients")
def test_put_client_1(mock_clients):
    app = create_app()
    with patch(
        "builtins.open", mock_open(read_data=json.dumps(mock_clients))
    ) as mock_file_open, patch(
        "os.path.getmtime", return_value=3
    ) as mock_getmtime, app.test_client() as app_test_client:
        response = app_test_client.get("/client/client-1")
        client_1 = response.json
        client_1["subscription"] = "soar.client-1.#"
        response = app_test_client.put("/client/client-1", json=client_1)
        assert response.status_code == 201
        assert "client_id" in response.json
        assert response.json["client_id"] == "client-1"
        assert response.json["subscription"] == "soar.client-1.#"
        assert "client_name" in response.json
        assert "secret" in response.json


@pytest.mark.usefixtures("mock_clients")
def test_delete_client_1(mock_clients):
    app = create_app()
    with patch(
        "builtins.open", mock_open(read_data=json.dumps(mock_clients))
    ) as mock_file_open, patch(
        "os.path.getmtime", return_value=3
    ) as mock_getmtime, app.test_client() as app_test_client:
        response = app_test_client.delete("/client/client-1")
        assert response.status_code == 204
